@@ -15,4 +15,7 @@ mcp = mcp_from_functions(
     ])
 
 def main():
-    mcp.run(transport="stdio")
\ No newline at end of file
+    mcp.run(transport="stdio")
+
+if __name__ == '__main__':
+    main()
\ No newline at end of file
